==> s3-0.9.0-sources.jar: software/amazon/awscdk/services/s3/PipelineSourceProps.java <==
package software.amazon.awscdk.services.s3;

/**
 * Construction properties of the {@link PipelineSource S3 source Action}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:58:01.385Z")
public interface PipelineSourceProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.s3.CommonPipelineSourceProps, software.amazon.awscdk.services.codepipeline.api.CommonActionProps {
    /**
     * The Amazon S3 bucket that stores the source code
     */
    software.amazon.awscdk.services.s3.BucketRef getBucket();
    /**
     * The Amazon S3 bucket that stores the source code
     */
    void setBucket(final software.amazon.awscdk.services.s3.BucketRef value);

    /**
     * @return a {@link Builder} of {@link PipelineSourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link PipelineSourceProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.s3.BucketRef _bucket;
        private java.lang.String _artifactName;
        private java.lang.String _bucketKey;
        @javax.annotation.Nullable
        private java.lang.Boolean _pollForSourceChanges;
        private software.amazon.awscdk.services.codepipeline.api.IStage _stage;

        /**
         * Sets the value of Bucket
         * @param value The Amazon S3 bucket that stores the source code
         * @return {@code this}
         */
        public Builder withBucket(final software.amazon.awscdk.services.s3.BucketRef value) {
            this._bucket = java.util.Objects.requireNonNull(value, "bucket is required");
            return this;
        }
        /**
         * Sets the value of ArtifactName
         * @param value The name of the source's output artifact. Output artifacts are used by CodePipeline as
inputs into other actions.
         * @return {@code this}
         */
        public Builder withArtifactName(final java.lang.String value) {
            this._artifactName = java.util.Objects.requireNonNull(value, "artifactName is required");
            return this;
        }
        /**
         * Sets the value of BucketKey
         * @param value The key within the S3 bucket that stores the source code.
         * @return {@code this}
         */
        public Builder withBucketKey(final java.lang.String value) {
            this._bucketKey = java.util.Objects.requireNonNull(value, "bucketKey is required");
            return this;
        }
        /**
         * Sets the value of PollForSourceChanges
         * @param value Whether or not AWS CodePipeline should poll for source changes
         * @return {@code this}
         */
        public Builder withPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
            this._pollForSourceChanges = value;
            return this;
        }
        /**
         * Sets the value of Stage
         * @param value The Pipeline Stage to add this Action to.
         * @return {@code this}
         */
        public Builder withStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this._stage = java.util.Objects.requireNonNull(value, "stage is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PipelineSourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public PipelineSourceProps build() {
            return new PipelineSourceProps() {
                private software.amazon.awscdk.services.s3.BucketRef $bucket = java.util.Objects.requireNonNull(_bucket, "bucket is required");
                private java.lang.String $artifactName = java.util.Objects.requireNonNull(_artifactName, "artifactName is required");
                private java.lang.String $bucketKey = java.util.Objects.requireNonNull(_bucketKey, "bucketKey is required");
                @javax.annotation.Nullable
                private java.lang.Boolean $pollForSourceChanges = _pollForSourceChanges;
                private software.amazon.awscdk.services.codepipeline.api.IStage $stage = java.util.Objects.requireNonNull(_stage, "stage is required");

                @Override
                public software.amazon.awscdk.services.s3.BucketRef getBucket() {
                    return this.$bucket;
                }

                @Override
                public void setBucket(final software.amazon.awscdk.services.s3.BucketRef value) {
                    this.$bucket = java.util.Objects.requireNonNull(value, "bucket is required");
                }

                @Override
                public java.lang.String getArtifactName() {
                    return this.$artifactName;
                }

                @Override
                public void setArtifactName(final java.lang.String value) {
                    this.$artifactName = java.util.Objects.requireNonNull(value, "artifactName is required");
                }

                @Override
                public java.lang.String getBucketKey() {
                    return this.$bucketKey;
                }

                @Override
                public void setBucketKey(final java.lang.String value) {
                    this.$bucketKey = java.util.Objects.requireNonNull(value, "bucketKey is required");
                }

                @Override
                public java.lang.Boolean getPollForSourceChanges() {
                    return this.$pollForSourceChanges;
                }

                @Override
                public void setPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
                    this.$pollForSourceChanges = value;
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
                    return this.$stage;
                }

                @Override
                public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
                    this.$stage = java.util.Objects.requireNonNull(value, "stage is required");
                }

            };
        }
    }

    /**
     * A proxy class which for javascript object literal which adhere to this interface.
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.s3.PipelineSourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The Amazon S3 bucket that stores the source code
         */
        @Override
        public software.amazon.awscdk.services.s3.BucketRef getBucket() {
            return this.jsiiGet("bucket", software.amazon.awscdk.services.s3.BucketRef.class);
        }

        /**
         * The Amazon S3 bucket that stores the source code
         */
        @Override
        public void setBucket(final software.amazon.awscdk.services.s3.BucketRef value) {
            this.jsiiSet("bucket", java.util.Objects.requireNonNull(value, "bucket is required"));
        }

        /**
         * The name of the source's output artifact. Output artifacts are used by CodePipeline as
         * inputs into other actions.
         */
        @Override
        public java.lang.String getArtifactName() {
            return this.jsiiGet("artifactName", java.lang.String.class);
        }

        /**
         * The name of the source's output artifact. Output artifacts are used by CodePipeline as
         * inputs into other actions.
         */
        @Override
        public void setArtifactName(final java.lang.String value) {
            this.jsiiSet("artifactName", java.util.Objects.requireNonNull(value, "artifactName is required"));
        }

        /**
         * The key within the S3 bucket that stores the source code.
         * @example 'path/to/file.zip'
         */
        @Override
        public java.lang.String getBucketKey() {
            return this.jsiiGet("bucketKey", java.lang.String.class);
        }

        /**
         * The key within the S3 bucket that stores the source code.
         * @example 'path/to/file.zip'
         */
        @Override
        public void setBucketKey(final java.lang.String value) {
            this.jsiiSet("bucketKey", java.util.Objects.requireNonNull(value, "bucketKey is required"));
        }

        /**
         * Whether or not AWS CodePipeline should poll for source changes
         * @default true
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Boolean getPollForSourceChanges() {
            return this.jsiiGet("pollForSourceChanges", java.lang.Boolean.class);
        }

        /**
         * Whether or not AWS CodePipeline should poll for source changes
         * @default true
         */
        @Override
        public void setPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
            this.jsiiSet("pollForSourceChanges", value);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
            return this.jsiiGet("stage", software.amazon.awscdk.services.codepipeline.api.IStage.class);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this.jsiiSet("stage", java.util.Objects.requireNonNull(value, "stage is required"));
        }
    }
}

==> s3-0.9.1-sources.jar: software/amazon/awscdk/services/s3/PipelineSourceProps.java <==
package software.amazon.awscdk.services.s3;

/**
 * Construction properties of the {@link PipelineSource S3 source Action}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:18:26.853Z")
public interface PipelineSourceProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.s3.CommonPipelineSourceProps, software.amazon.awscdk.services.codepipeline.api.CommonActionProps {
    /**
     * The Amazon S3 bucket that stores the source code
     */
    software.amazon.awscdk.services.s3.BucketRef getBucket();
    /**
     * The Amazon S3 bucket that stores the source code
     */
    void setBucket(final software.amazon.awscdk.services.s3.BucketRef value);

    /**
     * @return a {@link Builder} of {@link PipelineSourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link PipelineSourceProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.s3.BucketRef _bucket;
        private java.lang.String _artifactName;
        private java.lang.String _bucketKey;
        @javax.annotation.Nullable
        private java.lang.Boolean _pollForSourceChanges;
        private software.amazon.awscdk.services.codepipeline.api.IStage _stage;

        /**
         * Sets the value of Bucket
         * @param value The Amazon S3 bucket that stores the source code
         * @return {@code this}
         */
        public Builder withBucket(final software.amazon.awscdk.services.s3.BucketRef value) {
            this._bucket = java.util.Objects.requireNonNull(value, "bucket is required");
            return this;
        }
        /**
         * Sets the value of ArtifactName
         * @param value The name of the source's output artifact. Output artifacts are used by CodePipeline as
inputs into other actions.
         * @return {@code this}
         */
        public Builder withArtifactName(final java.lang.String value) {
            this._artifactName = java.util.Objects.requireNonNull(value, "artifactName is required");
            return this;
        }
        /**
         * Sets the value of BucketKey
         * @param value The key within the S3 bucket that stores the source code.
         * @return {@code this}
         */
        public Builder withBucketKey(final java.lang.String value) {
            this._bucketKey = java.util.Objects.requireNonNull(value, "bucketKey is required");
            return this;
        }
        /**
         * Sets the value of PollForSourceChanges
         * @param value Whether or not AWS CodePipeline should poll for source changes
         * @return {@code this}
         */
        public Builder withPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
            this._pollForSourceChanges = value;
            return this;
        }
        /**
         * Sets the value of Stage
         * @param value The Pipeline Stage to add this Action to.
         * @return {@code this}
         */
        public Builder withStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this._stage = java.util.Objects.requireNonNull(value, "stage is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PipelineSourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public PipelineSourceProps build() {
            return new PipelineSourceProps() {
                private software.amazon.awscdk.services.s3.BucketRef $bucket = java.util.Objects.requireNonNull(_bucket, "bucket is required");
                private java.lang.String $artifactName = java.util.Objects.requireNonNull(_artifactName, "artifactName is required");
                private java.lang.String $bucketKey = java.util.Objects.requireNonNull(_bucketKey, "bucketKey is required");
                @javax.annotation.Nullable
                private java.lang.Boolean $pollForSourceChanges = _pollForSourceChanges;
                private software.amazon.awscdk.services.codepipeline.api.IStage $stage = java.util.Objects.requireNonNull(_stage, "stage is required");

                @Override
                public software.amazon.awscdk.services.s3.BucketRef getBucket() {
                    return this.$bucket;
                }

                @Override
                public void setBucket(final software.amazon.awscdk.services.s3.BucketRef value) {
                    this.$bucket = java.util.Objects.requireNonNull(value, "bucket is required");
                }

                @Override
                public java.lang.String getArtifactName() {
                    return this.$artifactName;
                }

                @Override
                public void setArtifactName(final java.lang.String value) {
                    this.$artifactName = java.util.Objects.requireNonNull(value, "artifactName is required");
                }

                @Override
                public java.lang.String getBucketKey() {
                    return this.$bucketKey;
                }

                @Override
                public void setBucketKey(final java.lang.String value) {
                    this.$bucketKey = java.util.Objects.requireNonNull(value, "bucketKey is required");
                }

                @Override
                public java.lang.Boolean getPollForSourceChanges() {
                    return this.$pollForSourceChanges;
                }

                @Override
                public void setPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
                    this.$pollForSourceChanges = value;
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
                    return this.$stage;
                }

                @Override
                public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
                    this.$stage = java.util.Objects.requireNonNull(value, "stage is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.s3.PipelineSourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The Amazon S3 bucket that stores the source code
         */
        @Override
        public software.amazon.awscdk.services.s3.BucketRef getBucket() {
            return this.jsiiGet("bucket", software.amazon.awscdk.services.s3.BucketRef.class);
        }

        /**
         * The Amazon S3 bucket that stores the source code
         */
        @Override
        public void setBucket(final software.amazon.awscdk.services.s3.BucketRef value) {
            this.jsiiSet("bucket", java.util.Objects.requireNonNull(value, "bucket is required"));
        }

        /**
         * The name of the source's output artifact. Output artifacts are used by CodePipeline as
         * inputs into other actions.
         */
        @Override
        public java.lang.String getArtifactName() {
            return this.jsiiGet("artifactName", java.lang.String.class);
        }

        /**
         * The name of the source's output artifact. Output artifacts are used by CodePipeline as
         * inputs into other actions.
         */
        @Override
        public void setArtifactName(final java.lang.String value) {
            this.jsiiSet("artifactName", java.util.Objects.requireNonNull(value, "artifactName is required"));
        }

        /**
         * The key within the S3 bucket that stores the source code.
         * @example 'path/to/file.zip'
         */
        @Override
        public java.lang.String getBucketKey() {
            return this.jsiiGet("bucketKey", java.lang.String.class);
        }

        /**
         * The key within the S3 bucket that stores the source code.
         * @example 'path/to/file.zip'
         */
        @Override
        public void setBucketKey(final java.lang.String value) {
            this.jsiiSet("bucketKey", java.util.Objects.requireNonNull(value, "bucketKey is required"));
        }

        /**
         * Whether or not AWS CodePipeline should poll for source changes
         * @default true
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Boolean getPollForSourceChanges() {
            return this.jsiiGet("pollForSourceChanges", java.lang.Boolean.class);
        }

        /**
         * Whether or not AWS CodePipeline should poll for source changes
         * @default true
         */
        @Override
        public void setPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
            this.jsiiSet("pollForSourceChanges", value);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
            return this.jsiiGet("stage", software.amazon.awscdk.services.codepipeline.api.IStage.class);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this.jsiiSet("stage", java.util.Objects.requireNonNull(value, "stage is required"));
        }
    }
}
